#
# spec file for package libiscsi
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define         sover 10
Name:           libiscsi
Version:        1.20.0+git.20241207
Release:        1.1
Summary:        iSCSI client library and utilities
License:        GPL-2.0-only AND LGPL-2.1-only
URL:            https://github.com/sahlberg/libiscsi
Source0:        %{name}-%{version}.tar.gz
Source99:       baselibs.conf
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  bc
BuildRequires:  libgcrypt-devel
BuildRequires:  librdmacm-devel
BuildRequires:  libtool
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(cunit)
%{?suse_build_hwcaps_libs}

%description
libiscsi is a clientside library to implement the iSCSI protocol
that can be used to access resource of an iSCSI target.

%package -n %{name}%{sover}
Summary:        iSCSI client library and utilities

%description -n %{name}%{sover}
libiscsi is a clientside library to implement the iSCSI protocol
that can be used to access resource of an iSCSI target.

The library is fully asynchronous with regards to iSCSI commands and
SCSI tasks, but a synchronous layer is also provided for ease of use
for simpler applications.

%package utils
Summary:        Some utilities for %{name}

%description utils
libiscsi is a clientside library to implement the iSCSI protocol that can
be used to access resource of an iSCSI target.

This package contains utilities based on %{name}.

%package devel
Summary:        Development files for %{name}
Requires:       %{name}%{sover} = %{version}

%description devel
Development files for %{name}

%package test
Summary:        Test utilities for iSCSI

%description test
A comprehensive iSCSI transport and SCSI block device test suite based on
CUnit.

%prep
%autosetup

%build
autoreconf -fiv
%configure \
  --enable-manpages \
  --disable-werror  \
  --disable-static
%make_build

%install
%make_install
find %{buildroot} -type f -name "*.la" -delete -print

%ldconfig_scriptlets -n %{name}%{sover}

%files -n %{name}%{sover}
%{_libdir}/libiscsi.so.%{sover}*

%files utils
%license COPYING
%doc LICENCE-* README.md
%{_bindir}/iscsi-discard
%{_bindir}/iscsi-md5sum
%{_bindir}/iscsi-inq
%{_bindir}/iscsi-ls
%{_bindir}/iscsi-swp
%{_bindir}/iscsi-perf
%{_bindir}/iscsi-pr
%{_bindir}/iscsi-readcapacity16
%{_mandir}/man1/iscsi-inq.1%{?ext_man}
%{_mandir}/man1/iscsi-ls.1%{?ext_man}
%{_mandir}/man1/iscsi-swp.1%{?ext_man}
%{_mandir}/man1/iscsi-md5sum.1%{?ext_man}

%files devel
%{_libdir}/pkgconfig/libiscsi.pc
%{_includedir}/iscsi/
%{_libdir}/libiscsi.so

%files test
%{_bindir}/iscsi-test-cu
%{_mandir}/man1/iscsi-test-cu.1%{?ext_man}

%changelog
* Tue Dec 10 2024 Martin Pluskal <mpluskal@suse.com>
- Update to version 1.20.0+git.20241207:
  * fix: scan PDUs before exiting event_loop due to connect timedout
  * lib: finish event_loop on invalid fd
  * lib: reserve the fd on reconnect
  * Fix free pdu mismatch with alloc
  * Fix pdu indata of iser alloc and free mismatch
  * feat: add iscsi_reset_next_reconnect interface
  * For failing writes, show what is in the sector instead
  * libcunit1-dev is required for iscsi-test-cu to be build
  * install binaries and manpage to rpm
  * Add utils.h to dist_noinst_HEADERS
* Fri Jun  7 2024 Martin Pluskal <mpluskal@suse.com>
- Update to version 1.20.0+git.20240530:
  * fix use after free in recent commit
  * Add support for Data Digest
  * login: add support for gnutls
  * login: do not try to "emulate" the libgcrypt API
  * configure: add --with-libgcrypt option
  * A possible 'fix' for https://github.com/sahlberg/libiscsi/issues/415 This patch adds a timestamp before each logged line. That could help correlating a logging to a network-trace. Because of offsets in time between the tracer and the test and the DUT, this does not always help.
  * Manually set task to null after free to avoid double free issue
  * lun_reset cancelling lun tasks only
* Thu Feb 29 2024 Martin Pluskal <mpluskal@suse.com>
- Update to version 1.20.0+git.20240206:
  * spelling fixes: eventhough, shoudl, asyncronous, maxium, implicity
  * COPYING: stop mentioning ld_scsi
  * New version 1.20.0
  * Previously, 'task->status' was printed as decimal. In iscsi.h, the values that are put into it are defined as hexadecimal. This is a bit confusing (grepping through the code for 251658241 did not result in anything while the hex variant f000001 resulted in SCSI_STATUS_ERROR).
  * Fix for https://github.com/sahlberg/libiscsi/issues/409 'ms->pages' was not checked for being NULL. This can happen when a target does not return any pages.
  * Improve iSCSI PDU header dump
  * Abstract value_string as common utility
  * Drain DATAOUT PDU on timeout
* Tue Nov 14 2023 Martin Pluskal <mpluskal@suse.com>
- Update to version 1.19.0+git.20231114:
  * Log necessary message on internal reconnect
  * Dump opcode string in iscsi_dump_pdu_header()
  * Introduce helper function scsi_opcode_str
  * Declare value-string maps as static
  * Distinguish command timeout
  * doc: Add iscsi-md5sum
  * fixup! checking if task is in outqueue
  * checking if task is in outqueue
  * Add add  a timeout to the event_loop in sync.c
  * iscsi-discard: adapt block limits
  * gitignore: Add utils/iscsi-md5sum
  * iscsi-md5sum: Add new tool
  * gitignore: add utils/iscsi-discard
  * iscsi-discard: Add new tool
  * utils: use strtol instead of atoi
  * Add iscsi_set_fd_dup_cb
  * Add /utils/iscsi-pr into .gitignore
  * iscsi-perf: Add -h/--help
* Wed Mar  8 2023 Martin Pluskal <mpluskal@suse.com>
- Update to version 1.19.0+git.20230208:
  * iser: Remove unnecessary 'return;'
  * pdu: Remove temporary variables from functions
  * connect: Add check after malloc allocation
  * aros_compat: Add check after malloc allocation
- Build AVX2 enabled hwcaps library for x86_64-v3
* Mon Nov 28 2022 Martin Pluskal <mpluskal@suse.com>
- Update to version 1.19.0+git.20221112:
  * ci/build.sh: Enable parallel compilation
  * ci: Fix the Appveyor Linux and Windows builds
  * ci: Add ci/install.bat
  * Add CodeQL workflow for GitHub code scanning
  * test-tool: remove a redundant semicolon
  * lib/scsi-lowlevel: Make the REPORT LUNS unmarshalling code more flexible
  * Fix segmentation fault problem.
  * Check return value of scsi_malloc in order to avoid dereferencing NULL return value.
  * fix iscsi-ls parameter parse
  * iscsi-swp: handle setting of debug_level correctly
  * Update iscsi-dd.c
  * iscsi-inq: handle setting of debug_level correctly
  * Retain the immediate data param during login processing
* Wed Mar 16 2022 Martin Pluskal <mpluskal@suse.com>
- Update to version 1.19.0+git.20220303:
  * iscsi-command: Fix leak in iscsi_send_data_out
  * iscsi-pr: add persistent reservation tool
  * add iscsi_force_reconnect()
  * add libiscsi.syms to .gitignore
* Thu Dec  9 2021 Martin Pluskal <mpluskal@suse.com>
- Update to version 1.19.0+git.20210930:
  * iscsi-support: fix memory leak
  * add README.md to dist tarball
  * add libiscsi.syms.in to dist tarball
  * test-tool, xcopy: Fix target descriptor handling
  * iser: Fix a compiler warning triggered by the container_of() definition
  * configure: Remove -Wno-strict-aliasing
  * slist: Clean up the slist.h header file
  * slist: Make this header file compatible with C++
  * scsi-lowlevel.h: Include <assert.h>
  * examples/iscsi-dd: use stderr for all error text
  * examples/iscsi-dd: fix typos
  * ci: Add a github build action
  * test: fix ExtendedCopy.Large SKIPPED cases
  * configure.ac: Quote argument to m4_esyscmd() properly
  * Fixed several code style problems
  * test-tool: check that ReceiveCopyResults is implemented
  * lib: init version for 8Fh VPD page
  * ci: Enable MinGW
  * MinGW: Second step of porting to MinGW
  * configure.ac: Use AC_CONFIG_HEADERS() instead of AC_CONFIG_HEADER()
  * lib/libiscsi.syms: Sort alphabetically
  * ci: First phase of adding MingW support
  * configure.ac: Run autoupdate
  * README.md: Update
  * README: Rename into README.md
  * ci: Switch from Travis to AppVeyor
  * test-tool: Do not use empty initializers
* Thu Jun 24 2021 Martin Pluskal <mpluskal@suse.com>
- Update to version 1.19.0+git.20210523:
  * Port to MinGW
  * win32/win32_compat.c: Reformat this file
  * Enable -Wno-unused-parameter
  * Use __attribute__((format(printf, ...))) directly
  * build: Add -no-undefined where missing
  * build: Correct usage of LIBADD and LDADD
  * build: Remove bogus LDADD variables
  * Add header <strings.h> for strncasecmp
* Thu Apr 22 2021 Martin Pluskal <mpluskal@suse.com>
- Update to version 1.19.0+git.20210208:
  * test-tool: Change command_is_implemented from a global variable into an argument
  * test-tool: Move a logging statement into write_residuals_test()
  * test-tool: Add default clauses in recently modified switch statements
  * test-tool, residuals: Rename struct residuals_test_data members
  * test-tool: Add overwrite check for all test cases
  * test-tool: Change write residuals tests overwrite check according to FCP-4
  * test-tool: Refactoring residuals write tests
  * test-tool: Allow CHECK CONDITION in response to overflow/underflow
  * .travis.yml: Multiple changes
  * test-tool: add simple REPORT LUNS test
  * init: fix Wformat on 32-bit platforms
* Mon Dec 28 2020 Martin Pluskal <mpluskal@suse.com>
- Update to version 1.19.0+git.20201217:
  * Revert "specify number of blocks in write_same command"
  * iser: fix segmentation fault when task management pdu is received
  * iser: fix segmentation fault when async message pdu is received
* Thu Nov  5 2020 Martin Pluskal <mpluskal@suse.com>
- Update to version 1.19.0+git.20201023:
  * test-tool: add COMPARE AND WRITE MiscompareSense test
  * lib: parse Information fixed sense field
  * lib: parse Information sense descriptor type
  * lib: check length for sense key specific sense data descriptors
  * lib: drop generic sense data descriptor VALID check
  * test-tool: add version descriptor checks for more SBC-3 versions
  * test-tool: Fix CmdSN tests
  * test-tool/test_async_lu_reset_simple: Move an assert statement
  * Remove an unused function from the iSER code
  * test-tool: add LogoutDuringIOAsync test case
  * test-tool: rename async write dispatch/complete counters
  * pdu: fix use after free during cancellation
* Thu Aug 13 2020 Martin Pluskal <mpluskal@suse.com>
- Update to version 1.19.0+git.20200812:
  * .travis.yml: Also build for the ppc64le architecture
  * iscsi-ls: Fix iser url scheme parsing
  * test-tool: Use block_size instead of hardcoded 512 bytes
  * examples/iscsi-dd: use common init function for src and dst endpoints
  * examples/iscsi-dd: use common iscsi_endpoint struct
  * iscsi-perf: Add explicit casts to avoid two warnings
  * socket: Make the pdu timeout handling aware of old iscsi context
  * libiscsi: Make the cancellation aware of the pdus in old iscsi context
  * pdu: Remove the checking for iscsi->is_loggedin in iscsi_cancel_pdus()
  * libiscsi: Avoid discontinuities in cmdsn ordering in some cases
  * test-tool: Use block_size instead of hardcoded 512 bytes
  * exclude ld_iscsi.so from RPM
  * include iser-private.h in make dist tarball
* Tue May 26 2020 Martin Pluskal <mpluskal@suse.com>
- Update to version 1.19.0+git.20200521:
  * test-tool, compare and write: Reduce maximum number of blocks from 256 to 255
  * test_compareandwrite_invalid_dataout_size: Simplify this test
  * test-tool: Use asprintf() in sg_send_scsi_cmd()
  * test-tool: Fix a comment in sg_send_scsi_cmd()
  * test-tool: Split send_scsi_command()
  * socket: fix rewrite cmdsn of immediate pdus
  * iser: eliminate unnecessary memory allocations
  * iser: use `login_resp_buf` until login is finished
  * init: free iscsi->opaque before check mallocs/frees counter
  * reconnect: collect mallocs/frees of the previous reconnection
* Mon Apr 27 2020 Martin Liška <mliska@suse.cz>
- Enable -fcommon in order to fix boo#1160276.
* Tue Feb 18 2020 Martin Pluskal <mpluskal@suse.com>
- Update to version 1.19.0+git.20200212 (resolves boo#1160276):
  * drop the LD_PRELOAD tool
  * remove FIXME
  * Fix data segment length comparison to unsigned long
  * iser: queue pdus when cmdsn exceeds maxcmdsn
  * iser: send immediate data
  * iser: remove `__packed` from struct iser_cm_hdr declaration
  * iser: fix struct iser_rx_desc
  * test-tool: avoid use-after-free on iscsi_logout_sync
  * Use dynamic memory allocation instead of variable-length arrays
* Tue Sep 24 2019 Martin Pluskal <mpluskal@suse.com>
- Update build dependencies (libgcrypt)
* Tue Aug 13 2019 Martin Pluskal <mpluskal@suse.com>
- Update to version 1.19:
  * Mostly internal changes
- Drop no longer needed patches:
  * libiscsi-1.18.0-Fix-32bit-build.patch
  * libiscsi-rdma.patch
* Fri Jun 22 2018 mpluskal@suse.com
- Fix building of recent rdma (boo#1098749):
  * libiscsi-rdma.patch
* Wed Mar 14 2018 mpluskal@suse.com
- Morernise spec file with spec-clener
* Sat Apr  1 2017 mpluskal@suse.com
- Do not build with -Werror
* Mon Nov 14 2016 msuchanek@suse.com
- Fix 32bit build (gh#sahlberg/libiscsi#221, boo#1009456)
  * libiscsi-1.18.0-Fix-32bit-build.patch
* Sun Nov  6 2016 mpluskal@suse.com
- Exclued from building on 32 bit architectures
* Sun Nov  6 2016 jengelh@inai.de
- Resolve orthographic problems in description
* Sun Nov  6 2016 mpluskal@suse.com
- Update to version 1.18.0:
  * Various test updates
  * Add support for iSER
  * Add support for zero-copy reads
* Tue May 10 2016 mpluskal@suse.com
- Update to 1.17.0 (fate#320080)
  * Bugfix for a rare condition where if a  DATA-OUT PDU has a
    callback registered, it can cause a crash on reconnect/timeout.
* Thu May  5 2016 mpluskal@suse.com
- Update to 1.16.0
  * Various test updates.
  * Add tests for ExtendedCopy and ReceiveCopyResults
  * Add support for WRITE_ATOMIC_16 and tests
  * Multipath tests added
  * Persistent Reservation test updates.
  * Make sure to process target NOPs in the tests
  * Fix broken CHAP has handling.
* Thu Nov 26 2015 mpluskal@suse.com
- Initial package for libscsi 1.15.0
